==> hlw-core-0.0.2-20251024.073500-165-sources.jar: cn/gtmap/hlw/core/repository/GxYyFormRepository.java <==
package cn.gtmap.hlw.core.repository;

import cn.gtmap.hlw.core.base.BasePage;
import cn.gtmap.hlw.core.base.PageInfo;
import cn.gtmap.hlw.core.model.GxYyForm;

import java.util.List;

/**
 * 表单表(GxYyForm)表数据库访问层
 *
 * @author makejava
 * @since 2023-06-01 14:19:33
 */
public interface GxYyFormRepository {

    /**
     * 通过ID查询单条数据
     *
     * @param formid 主键
     * @return 实例对象
     */
    GxYyForm get(String formid);

    /**
     * 新增数据
     *
     * @param gxYyForm 实例对象
     * @return 影响行数
     */
    void save(GxYyForm gxYyForm);

    /**
     * 新增数据或更新数据
     *
     * @param gxYyForm 实例对象
     * @return 影响行数
     */
    void saveOrUpdate(GxYyForm gxYyForm);

    /**
     * 修改数据
     *
     * @param gxYyForm 实例对象
     * @return 影响行数
     */
    void update(GxYyForm gxYyForm);

    /**
     * 批量保存
     *
     * @param  gxYyFormList 实例对象集合
     * @return 影响行数
     */
    void saveBatch(List<GxYyForm> gxYyFormList);

    /**
     * 批量更新
     *
     * @param  gxYyFormList 实例对象集合
     * @return 影响行数
     */
    void updateBatch(List<GxYyForm> gxYyFormList);

    /**
     * 批量更新或保存
     *
     * @param  gxYyFormList 实例对象集合
     * @return 影响行数
     */
    void saveOrUpdateBatch(List<GxYyForm> gxYyFormList);

    /**
     * 修改数据
     *
     * @param formIds id集合
     * @return 影响行数
     */
    List<GxYyForm> getForms(List<String> formIds);

    /**
     * 根据formid查询信息
     *
     * @param formid
     * @return
     */
    List<GxYyForm> getByFormid(String formid);

    /**
     * 分页查询
     *
     * @param gxYyForm
     * @param basePage 分页参数
     * @return PageInfo<GxYyForm>
     */
    PageInfo<GxYyForm> queryPage(GxYyForm gxYyForm, BasePage basePage);

    /**
     * 根据uuid删除
     * @param uuid
     */
    void delete(String uuid);
}

==> hlw-core-0.0.2-20251119.064409-171-sources.jar: cn/gtmap/hlw/core/repository/GxYyFormRepository.java <==
package cn.gtmap.hlw.core.repository;

import cn.gtmap.hlw.core.base.BasePage;
import cn.gtmap.hlw.core.base.PageInfo;
import cn.gtmap.hlw.core.model.GxYyForm;

import java.util.List;

/**
 * 表单表(GxYyForm)表数据库访问层
 *
 * @author makejava
 * @since 2023-06-01 14:19:33
 */
public interface GxYyFormRepository {

    /**
     * 通过ID查询单条数据
     *
     * @param formid 主键
     * @return 实例对象
     */
    GxYyForm get(String formid);

    /**
     * 新增数据
     *
     * @param gxYyForm 实例对象
     * @return 影响行数
     */
    void save(GxYyForm gxYyForm);

    /**
     * 新增数据或更新数据
     *
     * @param gxYyForm 实例对象
     * @return 影响行数
     */
    void saveOrUpdate(GxYyForm gxYyForm);

    /**
     * 修改数据
     *
     * @param gxYyForm 实例对象
     * @return 影响行数
     */
    void update(GxYyForm gxYyForm);

    /**
     * 批量保存
     *
     * @param  gxYyFormList 实例对象集合
     * @return 影响行数
     */
    void saveBatch(List<GxYyForm> gxYyFormList);

    /**
     * 批量更新
     *
     * @param  gxYyFormList 实例对象集合
     * @return 影响行数
     */
    void updateBatch(List<GxYyForm> gxYyFormList);

    /**
     * 批量更新或保存
     *
     * @param  gxYyFormList 实例对象集合
     * @return 影响行数
     */
    void saveOrUpdateBatch(List<GxYyForm> gxYyFormList);

    /**
     * 修改数据
     *
     * @param formIds id集合
     * @return 影响行数
     */
    List<GxYyForm> getForms(List<String> formIds);

    /**
     * 根据formid查询信息
     *
     * @param formid
     * @return
     */
    List<GxYyForm> getByFormid(String formid);

    /**
     * 分页查询
     *
     * @param gxYyForm
     * @param basePage 分页参数
     * @return PageInfo<GxYyForm>
     */
    PageInfo<GxYyForm> queryPage(GxYyForm gxYyForm, BasePage basePage);

    /**
     * 根据uuid删除
     * @param uuid
     */
    void delete(String uuid);

    /**
     * 保存表单
     * @param gxYyForm 实例对象
     */
    void saveForm(GxYyForm gxYyForm);

    /**
     * 保存或更新表单
     * @param gxYyForm 实例对象
     */
    void saveOrUpdateForm(GxYyForm gxYyForm);

    /**
     * 根据formid查询
     * @param formIdList
     * @return:List<GxYyForm>
     */
    List<GxYyForm> listByFormIds(List<String> formIdList);

    /**
     * 批量保存
     * @param formList
     */
    void insertBatchSomeColumn(List<GxYyForm> formList);

    /**
     * 根据formid集合删除
     * @param formIdList
     */
    void deleteByFormIdList(List<String> formIdList);

    /**
     * 根据formid查询
     * @param formid
     * @return:List<GxYyForm>
     */
    List<GxYyForm> listByFormId(String formid);

    /**
     * 根据formid删除
     * @param formid
     */
    void deleteByFormId(String formid);
}
